#!/bin/bash

###################################################################################################
# Simple shell script to read in the WSJT-X ADI format logfile and convert it to HTML for website #
#                                                                                                 #
# Mike T - M0AWS - 27/01/22                                                                       #
#                                                                                                 #
###################################################################################################

###################################################################################################
# History:                                                                                        #
#           v0.1 - 27/01/22 - MikeT - M0AWS - Initial code write                                  #
#           v0.2 - 28/01/22 - MikeT - M0AWS - Tidy up formatting                                  #
#           v0.3 - 31/01/22 - MikeT - M0AWS - Code tidy and improvement                           #
#           v0.4 - 31/01/22 - MikeT - M0AWS - Added colour to table via CSS                       #
#           v0.5 - 03/02/22 - MikeT - M0AWS - Rewritten function process_log() to use column name #
#					      to identify data instead of position in row         #
#           v0.6 - 10/03/22 - MikeT - M0AWS - Added code to include map of digital contacts       #
#                                                                                                 #
###################################################################################################

############################
# Global Vars

VERSION="v0.6"
CALLSIGN="M0AWS"
DATE=`date`
ADIFILENAME="./wsjtx_log.adi"
HTMLFILENAME="./WSJT_log.html"
MAPFILE="m0aws-wsjtx-log-map.png"

############################
# Define Functions

function process_log() {

	tac $ADIFILENAME | while read LINE
	do
  	case $LINE in
		
		*call:*) DXCALL=`echo $LINE | grep -o 'call:[^[:space:]]*' | awk -F">" '{print $2}'`
		 	 GRIDSQUARE=`echo $LINE | grep -o '<gridsquare[^[:space:]]*' | awk -F">" '{print $2}'`
		 	 MODE=`echo $LINE | grep -o 'mode[^[:space:]]*' | awk -F">" '{print $2}'`
		 	 RSTSENT=`echo $LINE | grep -o 'rst_sent[^[:space:]]*' | awk -F">" '{print $2}'`
		 	 RSTRXD=`echo $LINE | grep -o 'rst_rcvd[^[:space:]]*' | awk -F">" '{print $2}'`
		 	 QSODATE=`echo $LINE | grep -o 'qso_date:[^[:space:]]*' | awk -F">" '{print $2}' | sed -n -e "s_\(....\)\(..\)\(..\)_\3/\2/\1_p"`
		 	 TIMEON=`echo $LINE | grep -o 'time_on[^[:space:]]*' | awk -F">" '{print $2}' | sed 's/../&:/g;s/:$//'`
		 	 #QSODATEOFF=`echo $LINE | grep -o 'qso_date_off[^[:space:]]*' | awk -F">" '{print $2}'`
		 	 TIMEOFF=`echo $LINE | grep -o 'time_off[^[:space:]]*' | awk -F">" '{print $2}' | sed 's/../&:/g;s/:$//'`
		 	 BAND=`echo $LINE | grep -o 'band[^[:space:]]*' | awk -F">" '{print $2}'`
		 	 FREQ=`echo $LINE | grep -o 'freq[^[:space:]]*' | awk -F">" '{print $2}'`
		 	 #MYCALL=`echo $LINE | grep -o 'station_callsign[^[:space:]]*' | awk -F">" '{print $2}'`
		 	 #MYGRIDSQ=`echo $LINE | grep -o 'my_gridsquare[^[:space:]]*' | awk -F">" '{print $2}'`
		 	 TXPWR=`echo $LINE | grep -o 'tx_pwr[^[:space:]]*' | awk -F">" '{print $2"w"}'`
		 	 COMMENT=`echo $LINE | awk -F"<comment" '{print $2}' | awk -F">" '{print $2}' | sed 's/<eor//g'`

		 	 echo -e "<tr>\n<td>$QSODATE</td>\n<td>$DXCALL</td>\n<td>$GRIDSQUARE</td>\n<td>$MODE</td>\n<td>$RSTSENT</td>\n<td>$RSTRXD</td>\n<td>$TIMEON</td>\n<td>$TIMEOFF</td>\n<td>$BAND</td>\n<td>$FREQ</td>\n<td>$TXPWR</td>\n<td>$COMMENT</td>\n</tr>" >> $HTMLFILENAME
		 	;;
  	esac
		
	done

}


function write_html_header() {
	echo -e "<!DOCTYPE html>\n<html>\n<style>\ntable, th, td {border:1px solid black;}\n       th { background-color: #A0A0A0; }\n       tr:nth-child(odd) {background-color: #E0E0E0;}\n       tr:nth-child(even) {background-color: #FFFF99;}\n</style>\n<body>\n<center><h2>$CALLSIGN WSJT-X Digital Modes Log updated $DATE</h2></center>\n" > $HTMLFILENAME

	# Hash out the line below if you don't want to include a map in the webpage.
	echo -e "<CENTER><img src=\"/$MAPFILE\" alt=\"$CALLSIGN Digital contacts map\" style=\"width:1024px;height:720;\"></CENTER>" >> $HTMLFILENAME
	#
	echo -e "<table style=\"width:100%\">\n<tr>\n<th>QSO DATE</th>\n<th>DX CALLSIGN</th>\n<th>DX GRID</th>\n<th>MODE</th>\n<th>RST SENT</th>\n<th>RST RXD</th>\n<th>TIME ON</th>\n<th>TIME OFF</th>\n<th>BAND</th>\n<th>FREQ Mhz</th>\n<th>TX PWR</th>\n<th>COMMENT</th>\n</tr>" >> $HTMLFILENAME
}


function write_html_footer() {
	echo -e "</table>\n<p>Web page generated by adi2html.sh $VERSION by M0AWS <a href=\"http://m0aws.co.uk\">http://m0aws.co.uk</a></p>\n</body>\n</html>\n" >> $HTMLFILENAME
}

############################
# main()

write_html_header
process_log
write_html_footer

